# Changelog

<!--
   You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.
   For helpful instructions, please see:
   https://github.com/plone/plone.releaser/blob/master/ADD-A-NEWS-ITEM.rst
-->

<!-- towncrier release notes start -->

## 1.0.0b9 (2026-03-25)


### Internal:

- Add llms plugin for documentation @erral 
- Add tests for documentation how-tos @erral 
- Fix docs base url @erral 

## 1.0.0b8 (2026-03-23)


### New features:

- dynamically set the value of the related Image, checking the TinyMCE control panel @erral [#24](https://github.com/codesyntax/cs_dynamicpages/issues/24)


### Internal:

- Add documentation @erral 

## 1.0.0b7 (2026-03-20)


### New features:

- Add tests @erral 


### Bug fixes:

- Return false if trying to add a view that exists to the registry @erral 
- Translate comments @erral 

## 1.0.0b6 (2026-03-12)


### New features:

- Style the template handling actions @libargutxi [#20](https://github.com/codesyntax/cs_dynamicpages/issues/20)

## 1.0.0b5 (2026-03-11)


### New features:

- Add row marker CSS classes @erral [#10](https://github.com/codesyntax/cs_dynamicpages/issues/10)
- Add template handling @erral 


### Bug fixes:

- Change the id for the content wrapping div @erral [#9](https://github.com/codesyntax/cs_dynamicpages/issues/9)
- Add name to the body-class adapter not to clash with other existing adapters @erral 


### Internal:

- - Fix and expand test coverage: fix pre-existing placeholder tests, add tests for utils, indexers, upgrade steps, behaviors, vocabularies, control panel and browser components @erral 

## 1.0.0b4 (2025-11-10)


### New features:

- - Add icons to views @libargutxi
  - Add row spacing configuration @libargutxi
  - Add behavior to set fetchpriority/loading attributes to images @libargutxi
  - Complete translations @erral [#7](https://github.com/codesyntax/cs_dynamicpages/issues/7)

## 1.0.0b3 (2025-10-17)


### New features:

- Add more javascript code to the frontend @libargutxi [#5](https://github.com/codesyntax/cs_dynamicpages/issues/5)
- New configuration options @libargutxi 

## 1.0.0b2 (2025-10-08)


### New features:

- Publish created rows folder @libargutxi [#4](https://github.com/collective/cs_dynamicpages/issues/4)

## 1.0.0b1 (2025-10-08)


### Internal:

- Initial release @codesyntax
